Task: Dialog Based Language Learning: bAbI Task
================================================
Description: Short dialogs based on the bAbI tasks, but in the form of a question from a teacher, the answer from the student, and finally a comment on the answer from the teacher. The aim is to find learning models that use the comments to improve. From Weston '16. 

Link: https://arxiv.org/abs/1604.06045. Tasks can be accessed with a format like: 'parlai display_data -t dbll_babi:task:2_p0.5' which specifies task 2, and policy with 0.5 answers correct, see the paper for more details of the tasks.

Tags: #DBLL-bAbI, #All, #Goal

